/* docs/source/_static/version_tabs.css */

.version-tabs-container {
  display: inline-flex;
  border-radius: 9999px;
  border: 1px solid var(--color-foreground-border);
  padding: 2px;
  gap: 2px;
  margin-bottom: 0.5rem;
  background-color: var(--color-background-floating);
}

.version-tab {
  display: inline-block;
  padding: 0.15rem 0.9rem;
  font-size: 0.85rem;
  border-radius: 9999px;
  text-decoration: none;
  border: none;
  color: var(--color-foreground-muted);
}

.version-tab:hover {
  text-decoration: none;
  background-color: var(--color-background-hover);
}

.version-tab.selected {
  background-color: var(--color-brand-primary);
  color: var(--color-background-primary);
}
